@@ -2,9 +2,16 @@ from enum import Enum
 from ipaddress import IPv4Address, IPv6Address
 from typing import Optional, Tuple, Union
 
+from pycaracal import Reply
+
 Flow = Tuple[int, IPv6Address, int, int]
+"""The 4-tuple that influences the flow ID in per-flow load-balancing."""
 IPAddress = Union[IPv4Address, IPv6Address]
-Link = Tuple[Optional[IPv6Address], Optional[IPv6Address]]
+"""An IPv4 or IPv6 address."""
+Link = Tuple[int, Optional[IPv6Address], Optional[IPv6Address]]
+"""A pair of IP address between two consecutive TTLs, for the same flow ID."""
+Pair = Tuple[int, Optional[Reply], Optional[Reply]]
+"""A pair of replies between two consecutive TTLs, for the same flow ID."""
 
 
 class DestinationType(Enum):
